NAME = "blue_fusion"

ICON = "🔮"

DESCRIPTION = f"{ICON} 2025 IEEE GRSS Data Fusion Contest"

VERSION = "4.12.1"

REPO_NAME = "blue-fusion"

MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-fusion/marquee.png?raw=true"

ALIAS = "@fusion"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
